@@ -12,7 +12,7 @@
 
 
 
-#if defined(__CC_ARM) || defined(__arm)	/* ARMѥ */
+#if defined(__CC_ARM) || defined(__arm__)	/* ARMѥ */
 
 #include "arm/hospac.h"	
 
@@ -41,6 +41,9 @@
 #elif defined(__i386__)	/* i386-elf-gcc */
 #include "ia32/hospac.h"
 
+#elif defined(__mips__) /* mips-elf-gcc */
+#include "mips/hospac.h"
+
 #else
 
 #include "hospac.h"		/* ̤Ǥʤϥ󥯥롼ɥѥλԤ */
